@@ -1,7 +1,7 @@
 package App::lcpan;
 
-our $DATE = '2015-04-21'; # DATE
-our $VERSION = '0.24'; # VERSION
+our $DATE = '2015-04-22'; # DATE
+our $VERSION = '0.25'; # VERSION
 
 use 5.010001;
 use strict;
@@ -214,7 +214,7 @@ sub _create_schema {
                  has_metajson INTEGER,
                  has_metayml INTEGER,
                  has_makefilepl INTEGER,
-                 has_buildpl INTEGER,
+                 has_buildpl INTEGER
             )',
             'CREATE UNIQUE INDEX ix_file__name ON file(name)',
 
@@ -1606,7 +1606,7 @@ our %deps_args = (
 
 $SPEC{'deps'} = {
     v => 1.1,
-    summary => 'List dependencies of a module, data from local CPAN',
+    summary => 'List dependencies',
     description => <<'_',
 
 By default only runtime requires are displayed. To see prereqs for other phases
@@ -1661,7 +1661,7 @@ sub deps {
 
 $SPEC{'rdeps'} = {
     v => 1.1,
-    summary => 'List reverse dependencies of a module, data from local CPAN',
+    summary => 'List reverse dependencies',
     args => {
         %common_args,
         %mods_args,
@@ -1729,7 +1729,7 @@ App::lcpan - Manage your local CPAN mirror
 
 =head1 VERSION
 
-This document describes version 0.24 of App::lcpan (from Perl distribution App-lcpan), released on 2015-04-21.
+This document describes version 0.25 of App::lcpan (from Perl distribution App-lcpan), released on 2015-04-22.
 
 =head1 SYNOPSIS
 
@@ -1811,7 +1811,7 @@ return array of records.
 
 =head2 deps(%args) -> [status, msg, result, meta]
 
-List dependencies of a module, data from local CPAN.
+List dependencies.
 
 By default only runtime requires are displayed. To see prereqs for other phases
 (e.g. configure, or build, or ALL) or for other relationships (e.g. recommends,
@@ -2051,7 +2051,7 @@ will return array of records.
 
 =head2 rdeps(%args) -> [status, msg, result, meta]
 
-List reverse dependencies of a module, data from local CPAN.
+List reverse dependencies.
 
 Arguments ('*' denotes required arguments):
 
