@@ -1,7 +1,7 @@
 package App::lcpan::Cmd::deps;
 
-our $DATE = '2015-04-21'; # DATE
-our $VERSION = '0.24'; # VERSION
+our $DATE = '2015-04-22'; # DATE
+our $VERSION = '0.25'; # VERSION
 
 use 5.010;
 use strict;
@@ -15,7 +15,7 @@ $SPEC{handle_cmd} = $App::lcpan::SPEC{deps};
 *handle_cmd = \&App::lcpan::deps;
 
 1;
-# ABSTRACT: List dependencies of a module, data from local CPAN
+# ABSTRACT: List dependencies
 
 __END__
 
@@ -25,18 +25,18 @@ __END__
 
 =head1 NAME
 
-App::lcpan::Cmd::deps - List dependencies of a module, data from local CPAN
+App::lcpan::Cmd::deps - List dependencies
 
 =head1 VERSION
 
-This document describes version 0.24 of App::lcpan::Cmd::deps (from Perl distribution App-lcpan), released on 2015-04-21.
+This document describes version 0.25 of App::lcpan::Cmd::deps (from Perl distribution App-lcpan), released on 2015-04-22.
 
 =head1 FUNCTIONS
 
 
 =head2 handle_cmd(%args) -> [status, msg, result, meta]
 
-List dependencies of a module, data from local CPAN.
+List dependencies.
 
 By default only runtime requires are displayed. To see prereqs for other phases
 (e.g. configure, or build, or ALL) or for other relationships (e.g. recommends,
